@@ -1,4 +1,4 @@
-// Copyright (C) 2018-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2018-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -10,7 +10,6 @@
 
 #include <cc/command_interpreter.h>
 #include <exceptions/exceptions.h>
-#include <hooks/hooks_parser.h>
 #include <netconf/netconf_cfg_mgr.h>
 #include <netconf/parser_context.h>
 #include <netconf/tests/test_libraries.h>
@@ -178,7 +177,7 @@ TEST(NetconfCfgMgr, contextGlobals) {
     EXPECT_NE(0, globals->mapValue().size());
 
     // Maps and lists should be excluded.
-    for (auto it : globals->mapValue()) {
+    for (auto const& it : globals->mapValue()) {
         if (it.first == "astring") {
             ASSERT_EQ(Element::string, it.second->getType());
             EXPECT_EQ("okay", it.second->stringValue());
@@ -378,26 +377,6 @@ TEST(NetconfParser, badSocketType) {
 /// @brief Class used for testing CfgMgr
 class NetconfParserTest : public isc::process::ConfigParseTest {
 public:
-    virtual void SetUp() {
-        resetHooksPath();
-    }
-
-    virtual void TearDown() {
-        resetHooksPath();
-    }
-
-    /// @brief Sets the Hooks path from which hooks can be loaded.
-    /// @param explicit_path path to use as the hooks path.
-    void setHooksTestPath(const std::string explicit_path = "") {
-        HooksLibrariesParser::getHooksPath(true,
-                                           (!explicit_path.empty() ?
-                                            explicit_path : NETCONF_HOOKS_TEST_PATH));
-    }
-
-    /// @brief Resets the hooks path to DEFAULT_HOOKS_PATH.
-    void resetHooksPath() {
-        HooksLibrariesParser::getHooksPath(true);
-    }
 
     /// @brief Tries to load input text as a configuration
     ///
@@ -698,8 +677,6 @@ TEST_F(NetconfParserTest, configParseInvalidSocketUrl) {
 // name. In particular, it checks if such a library exists. Therefore we
 // can't use NETCONF_CONFIGS[4] as is, but need to run it through path replacer.
 TEST_F(NetconfParserTest, configParseHooks) {
-    setHooksTestPath();
-
     // Create the configuration with proper lib path.
     string cfg = pathReplacer(NETCONF_CONFIGS[4], BASIC_CALLOUT_LIBRARY);
     // The configuration should be successful.
