@@ -29,7 +29,7 @@ using namespace isc::util;
 namespace isc {
 namespace dhcp {
 
-isc::asiolink::IOServicePtr MySqlConfigBackendImpl::io_service_ = isc::asiolink::IOServicePtr();
+isc::asiolink::IOServicePtr MySqlConfigBackendImpl::io_service_;
 
 MySqlConfigBackendImpl::
 ScopedAuditRevision::ScopedAuditRevision(MySqlConfigBackendImpl* impl,
@@ -86,6 +86,11 @@ MySqlConfigBackendImpl(const std::string& space,
     }
 }
 
+MySqlConfigBackendImpl::~MySqlConfigBackendImpl() {
+    /// nothing to do there. The conn_ connection will be deleted and its dtor
+    /// will take care of releasing the compiled statements and similar.
+}
+
 MySqlBindingPtr
 MySqlConfigBackendImpl::createBinding(const Triplet<uint32_t>& triplet) {
     if (triplet.unspecified()) {
