@@ -11,7 +11,7 @@
 #include <dhcp/option_space.h>
 #include <exceptions/exceptions.h>
 #include <util/encode/encode.h>
-#include <util/io_utilities.h>
+#include <util/io.h>
 
 #include <boost/make_shared.hpp>
 
