@@ -48,9 +48,6 @@ namespace {
 /// @brief IP address to which HTTP service is bound.
 const std::string SERVER_ADDRESS = "127.0.0.1";
 
-/// @brief IPv6 address to whch HTTP service is bound.
-const std::string IPV6_SERVER_ADDRESS = "::1";
-
 /// @brief Port number to which HTTP service is bound.
 const unsigned short SERVER_PORT = 18123;
 
@@ -60,10 +57,6 @@ const long REQUEST_TIMEOUT = 10000;
 /// @brief Persistent connection idle timeout used in most of the tests (ms).
 const long IDLE_TIMEOUT = 10000;
 
-/// @brief Persistent connection idle timeout used in tests where idle connections
-/// are tested (ms).
-const long SHORT_IDLE_TIMEOUT = 200;
-
 /// @brief Test timeout (ms).
 const long TEST_TIMEOUT = 10000;
 
@@ -659,11 +652,7 @@ public:
             client->close();
         }
         test_timer_.cancel();
-        io_service_->restart();
-        try {
-            io_service_->poll();
-        } catch (...) {
-        }
+        io_service_->stopAndPoll();
     }
 
     /// @brief Connect to the endpoint.
@@ -696,6 +685,7 @@ public:
     /// @param timeout Optional value specifying for how long the io service
     /// should be ran.
     void runIOService(long timeout = 0) {
+        io_service_->stop();
         io_service_->restart();
 
         if (timeout > 0) {
@@ -704,8 +694,7 @@ public:
                                         timeout, IntervalTimer::ONE_SHOT);
         }
         io_service_->run();
-        io_service_->restart();
-        io_service_->poll();
+        io_service_->stopAndPoll(false);
     }
 
     /// @brief Returns HTTP OK response expected by unit tests.
